CountryLookupResult class
Result object for locale-to-country resolution.
Constructors
- CountryLookupResult.countryNotSupported({String? resolvedAlpha2})
-
factory
-
factory
- CountryLookupResult.success({required CountryDetails details, required String resolvedAlpha2})
-
factory
Properties
- details → CountryDetails?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isSuccess → bool
-
no setter
- resolvedAlpha2 → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CountryLookupStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override